@@ -1,59 +1,24 @@
 #-----------------------------------------------------------------------------
 #
-#	$Id : Meta.pm 2.011 2008-09-16 JMG$
+#	$Id : Meta.pm 2.013 2009-05-24 JMG$
 #
 #	Created and maintained by Jean-Marie Gouarne
-#	Copyright 2008 by Genicorp, S.A. (www.genicorp.com)
+#	Copyright 2009 by Genicorp, S.A. (www.genicorp.com)
 #
 #-----------------------------------------------------------------------------
 
 package	OpenOffice::OODoc::Meta;
 use	5.008_000;
-our	$VERSION	= 2.011;
-
-use	OpenOffice::OODoc::XPath	2.226;
-require Exporter;
-our	@ISA		= qw ( OpenOffice::OODoc::XPath Exporter );
-our	@EXPORT		= qw
-				(
-				ooLocaltime	ooTimelocal
-				odfLocaltime	odfTimelocal
-				);
+our	$VERSION	= 2.013;
+use	OpenOffice::OODoc::XPath	2.229;
+our	@ISA		= qw ( OpenOffice::OODoc::XPath );
 
 #-----------------------------------------------------------------------------
 
 BEGIN
 	{
-	*ooLocaltime			= *odfLocaltime;
-	*ooTimelocal			= *odfTimelocal;
-	*version			= *editing_cycles;
-	}
-
-#-----------------------------------------------------------------------------
-# date conversion from standard Perl localtime to OOo metadata format
-
-sub	odfLocaltime
-	{
-	my $time = shift || time();
-	my @t = localtime($time);
-	return sprintf
-			(
-			"%04d-%02d-%02dT%02d:%02d:%02d",
-			$t[5] + 1900, $t[4] + 1, $t[3], $t[2], $t[1], $t[0]
-			);
-	}
-
-#-----------------------------------------------------------------------------
-# date conversion from OOo metadata format to standard time()
-
-sub	odfTimelocal
-	{
-	require Time::Local;
-
-	my $ootime = shift;
-	return undef unless $ootime;
-	$ootime =~ /(\d*)-(\d*)-(\d*)T(\d*):(\d*):(\d*)/;
-	return Time::Local::timelocal($6, $5, $4, $3, $2 - 1, $1); 
+	*author			= *creator;
+	*version		= *editing_cycles;
 	}
 
 #-----------------------------------------------------------------------------
@@ -430,7 +395,6 @@ sub	user_defined
 			$self->setAttribute($element, 'meta:name', $key);
 			$self->setText($element, $new_fields{$key});
 			$count++;
-			last if $count > 3;
 			}
 		}
 	
@@ -447,6 +411,58 @@ sub	user_defined
 
 #-----------------------------------------------------------------------------
 
+sub	getUserProperty
+	{
+	my $self	= shift;
+	my $name	= $self->inputTextConversion(shift) or return undef;
+	my $property	= $self->getNodeByXPath
+		("//meta:user-defined[\@meta:name=\"$name\"]")
+		or return undef;
+
+	my $type	= $self->getAttribute($property, 'meta:value-type');
+	my $value	= $self->getText($property);
+
+	return (wantarray) ? ($type, $value) : $value;
+	}
+
+#-----------------------------------------------------------------------------
+
+sub	setUserProperty
+	{
+	my $self	= shift;
+	my $name	= shift or return undef;
+	my %opt		= @_;
+	my $n		= $self->inputTextConversion($name);
+	my $property	= $self->getNodeByXPath
+		("//meta:user-defined[\@meta:name=\"$n\"]");
+	unless ($property)
+		{
+		$property = $self->appendElement
+			(
+			$self->{'body'}, 'meta:user-defined',
+			);
+		$self->setAttribute($property, 'meta:name', $name);
+		}
+	$opt{'type'} = 'string' unless defined $opt{'type'};
+	$self->setAttribute($property, 'meta:value-type', $opt{'type'});
+	$self->setText($property, $opt{'value'});
+	return (wantarray) ? ($opt{'type'}, $opt{'value'}) : $opt{'value'};
+	}
+
+#-----------------------------------------------------------------------------
+
+sub	removeUserProperty
+	{
+	my $self	= shift;
+	my $name	= $self->inputTextConversion(shift);
+	return undef unless defined $name;
+	my $property	= $self->getNodeByXPath
+		("//meta:user-defined[\@meta:name=\"$name\"]");
+	return $self->removeElement($property);
+	}
+
+#-----------------------------------------------------------------------------
+
 sub	statistic
 	{
 	my $self	= shift;
